import { Component, ElementRef, EventEmitter, Input, Output, NgModule } from '@angular/core';
import { Spinner } from 'spin.js';
import { CommonModule } from '@angular/common';

var NgxSpinjsComponent = /** @class */ (function () {
    function NgxSpinjsComponent(element) {
        this.element = element;
        this.options = {};
        this.spinUpdate = new EventEmitter();
        this.show = false;
    }
    NgxSpinjsComponent.prototype.ngOnDestroy = function () {
        this.spinner = null;
    };
    NgxSpinjsComponent.prototype.ngOnChanges = function (changes) {
        if (changes["toggleSpinner"]) {
            if (changes["toggleSpinner"].isFirstChange()) {
                this.initSpinner();
            }
            if (changes["toggleSpinner"].currentValue) {
                this.startSpin();
            }
            else {
                this.stopSpin();
            }
        }
    };
    NgxSpinjsComponent.prototype.initSpinner = function () {
        var options = {
            lines: this.options.lines ? this.options.lines : 12,
            length: this.options.length ? this.options.length : 16,
            width: this.options.width ? this.options.width : 5,
            radius: this.options.radius ? this.options.radius : 16,
            scale: this.options.scale ? this.options.scale : 0.8,
            corners: this.options.corners ? this.options.corners : 1,
            rotate: this.options.rotate ? this.options.rotate : 0,
            direction: this.options.direction ? this.options.direction : 1,
            color: this.options.color ? this.options.color : '#444444',
            speed: this.options.speed ? this.options.speed : 1.5,
            trail: this.options.trail ? this.options.trail : 80,
            shadow: this.options.shadow ? this.options.shadow : 'none',
            className: this.options.className ? this.options.className : 'spinner',
            zIndex: this.options.zIndex ? this.options.zIndex : 2e9,
            top: this.options.top ? this.options.top : '50%',
            left: this.options.left ? this.options.left : '50%',
            position: this.options.position ? this.options.position : 'absolute'
        };
        this.spinner = new Spinner(options);
    };
    NgxSpinjsComponent.prototype.startSpin = function () {
        this.show = true;
        this.spinner.spin(this.element.nativeElement);
        this.spinUpdate.next(true);
    };
    NgxSpinjsComponent.prototype.stopSpin = function () {
        this.show = false;
        this.spinner.stop();
        this.spinUpdate.next(false);
    };
    return NgxSpinjsComponent;
}());
NgxSpinjsComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-spinjs',
                template: '<div [class.overlay-loader]="backdrop" [style.display]="show === true ? \'inherit\' : \'none\'"></div>',
                styles: [".overlay-loader{position:absolute;top:0;right:0;bottom:0;left:0;z-index:1000;background-color:rgba(255,255,255,.7)}"]
            },] },
];
NgxSpinjsComponent.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
NgxSpinjsComponent.propDecorators = {
    "backdrop": [{ type: Input },],
    "options": [{ type: Input },],
    "toggleSpinner": [{ type: Input },],
    "spinUpdate": [{ type: Output },],
};
var NgxSpinjsModule = /** @class */ (function () {
    function NgxSpinjsModule() {
    }
    return NgxSpinjsModule;
}());
NgxSpinjsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    NgxSpinjsComponent
                ],
                exports: [
                    NgxSpinjsComponent
                ]
            },] },
];

export { NgxSpinjsModule, NgxSpinjsComponent as ɵa };
//# sourceMappingURL=ngx-spinjs.js.map
